@@ -14,14 +14,16 @@
  *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *      GNU General Public License for more details.
  *
- *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *      You should have received a copy of the GNU General Public License along
+ *      with this program; if not, write to the Free Software Foundation, Inc.,
+ *      51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 
 #ifndef GEANY_ENTRY_ACTION_H
-#define GEANY_ENTRY_ACTION_H
+#define GEANY_ENTRY_ACTION_H 1
+
+#include "gtkcompat.h"
 
 G_BEGIN_DECLS
 
