@@ -14,15 +14,16 @@
  *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *      GNU General Public License for more details.
  *
- *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- *
+ *      You should have received a copy of the GNU General Public License along
+ *      with this program; if not, write to the Free Software Foundation, Inc.,
+ *      51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef GEANY_PREFS_H
 #define GEANY_PREFS_H 1
 
+#include <glib.h>
+
 G_BEGIN_DECLS
 
 /** General Preferences dialog settings. */
@@ -38,12 +39,10 @@ typedef struct GeanyPrefs
 	gboolean		auto_focus;
 	gchar			*default_open_path;	/**< Default path to look for files when no other path is appropriate. */
 	gchar			*custom_plugin_path;
+	gboolean		save_wingeom;
 }
 GeanyPrefs;
 
-extern GeanyPrefs prefs;
-
-
 /** Tools preferences */
 typedef struct GeanyToolPrefs
 {
@@ -54,11 +53,19 @@ typedef struct GeanyToolPrefs
 }
 GeanyToolPrefs;
 
-extern GeanyToolPrefs tool_prefs;
 
+#ifdef GEANY_PRIVATE
+
+extern GeanyPrefs prefs;
+
+extern GeanyToolPrefs tool_prefs;
 
 void prefs_show_dialog(void);
 
+void prefs_kb_search_name(const gchar *search);
+
+#endif /* GEANY_PRIVATE */
+
 G_END_DECLS
 
-#endif
+#endif /* GEANY_PREFS_H */
