@@ -31,18 +31,72 @@
  * @see scintilla_send_message().
  */
 
-#include <string.h>
-
-#include "geany.h"
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
 
 #include "sciwrappers.h"
+
 #include "utils.h"
 
-#define SSM(s, m, w, l) scintilla_send_message(s, m, w, l)
+#include <string.h>
+
+
+#ifndef NDEBUG
+
+sptr_t sci_send_message_internal (const gchar *file, guint line, ScintillaObject *sci,
+	guint msg, uptr_t wparam, sptr_t lparam)
+{
+	sptr_t result;
+	gint status;
+
+	scintilla_send_message(sci, SCI_SETSTATUS, 0, 0);
+	result = scintilla_send_message(sci, msg, wparam, lparam);
+	status = scintilla_send_message(sci, SCI_GETSTATUS, 0, 0);
+
+	if (status != 0)
+	{
+		const gchar *sub_msg = "unknown";
+		switch (status)
+		{
+			case SC_STATUS_FAILURE:
+				sub_msg = "generic failure";
+				break;
+			case SC_STATUS_BADALLOC:
+				sub_msg = "memory is exhausted";
+				break;
+			case SC_STATUS_WARN_REGEX:
+				sub_msg = "regular expression is invalid";
+				break;
+			default:
+				if (status >= SC_STATUS_WARN_START)
+					sub_msg = "unknown warning";
+				else
+					sub_msg = "unknown failure";
+				break;
+		}
+#define SCI_STATUS_FORMAT_STRING "%s:%u: scintilla has non-zero status " \
+			"code '%d' after sending message '%u' to instance '%p' with " \
+			"wParam='%lu' and lParam='%ld': %s"
+		if (status >= SC_STATUS_WARN_START)
+		{
+			g_warning(SCI_STATUS_FORMAT_STRING, file, line, status, msg,
+				(gpointer)sci, wparam, lparam, sub_msg);
+		}
+		else
+		{
+			g_critical(SCI_STATUS_FORMAT_STRING, file, line, status, msg,
+				(gpointer)sci, wparam, lparam, sub_msg);
+		}
+	}
+
+	return result;
+}
+#endif
 
 
 /* line numbers visibility */
-void sci_set_line_numbers(ScintillaObject *sci, gboolean set, gint extra_width)
+void sci_set_line_numbers(ScintillaObject *sci, gboolean set)
 {
 	if (set)
 	{
@@ -52,11 +106,6 @@ void sci_set_line_numbers(ScintillaObject *sci, gboolean set, gint extra_width)
 
 		g_snprintf(tmp_str, 15, "_%d", len);
 		width = sci_text_width(sci, STYLE_LINENUMBER, tmp_str);
-		if (extra_width)
-		{
-			g_snprintf(tmp_str, 15, "%d", extra_width);
-			width += sci_text_width(sci, STYLE_LINENUMBER, tmp_str);
-		}
 		SSM(sci, SCI_SETMARGINWIDTHN, 0, width);
 		SSM(sci, SCI_SETMARGINSENSITIVEN, 0, FALSE); /* use default behaviour */
 	}
@@ -183,6 +232,7 @@ void sci_add_text(ScintillaObject *sci, const gchar *text)
 /** Sets all text.
  * @param sci Scintilla widget.
  * @param text Text. */
+GEANY_API_SYMBOL
 void sci_set_text(ScintillaObject *sci, const gchar *text)
 {
 	if( text != NULL ){ /* if null text is passed to scintilla will segfault */
@@ -220,6 +270,7 @@ void sci_redo(ScintillaObject *sci)
 /** Begins grouping a set of edits together as one Undo action.
  * You must call sci_end_undo_action() after making your edits.
  * @param sci Scintilla @c GtkWidget. */
+GEANY_API_SYMBOL
 void sci_start_undo_action(ScintillaObject *sci)
 {
 	SSM(sci, SCI_BEGINUNDOACTION, 0, 0);
@@ -229,6 +280,7 @@ void sci_start_undo_action(ScintillaObject *sci)
 /** Ends grouping a set of edits together as one Undo action.
  * @param sci Scintilla @c GtkWidget.
  * @see sci_start_undo_action(). */
+GEANY_API_SYMBOL
 void sci_end_undo_action(ScintillaObject *sci)
 {
 	SSM(sci, SCI_ENDUNDOACTION, 0, 0);
@@ -271,16 +323,11 @@ void sci_zoom_off(ScintillaObject *sci)
 }
 
 
-gint sci_get_zoom(ScintillaObject *sci)
-{
-	return (gint) SSM(sci, SCI_GETZOOM, 0, 0);
-}
-
-
 /** Sets a line marker.
  * @param sci Scintilla widget.
  * @param line_number Line number.
  * @param marker Marker number. */
+GEANY_API_SYMBOL
 void sci_set_marker_at_line(ScintillaObject *sci, gint line_number, gint marker)
 {
 	SSM(sci, SCI_MARKERADD, (uptr_t) line_number, marker);
@@ -291,6 +338,7 @@ void sci_set_marker_at_line(ScintillaObject *sci, gint line_number, gint marker)
  * @param sci Scintilla widget.
  * @param line_number Line number.
  * @param marker Marker number. */
+GEANY_API_SYMBOL
 void sci_delete_marker_at_line(ScintillaObject *sci, gint line_number, gint marker)
 {
 	SSM(sci, SCI_MARKERDELETE, (uptr_t) line_number, marker);
@@ -302,6 +350,7 @@ void sci_delete_marker_at_line(ScintillaObject *sci, gint line_number, gint mark
  * @param line Line number.
  * @param marker Marker number.
  * @return Whether it's set. */
+GEANY_API_SYMBOL
 gboolean sci_is_marker_set_at_line(ScintillaObject *sci, gint line, gint marker)
 {
 	gint state;
@@ -359,6 +408,7 @@ gint sci_marker_previous(ScintillaObject *sci, gint line, gint marker_mask, gboo
  * @param sci Scintilla widget.
  * @param position Position.
  * @return The line. */
+GEANY_API_SYMBOL
 gint sci_get_line_from_position(ScintillaObject *sci, gint position)
 {
 	return (gint) SSM(sci, SCI_LINEFROMPOSITION, (uptr_t) position, 0);
@@ -369,6 +419,7 @@ gint sci_get_line_from_position(ScintillaObject *sci, gint position)
  * @param sci Scintilla widget.
  * @param position Position.
  * @return The column. */
+GEANY_API_SYMBOL
 gint sci_get_col_from_position(ScintillaObject *sci, gint position)
 {
 	return (gint) SSM(sci, SCI_GETCOLUMN, (uptr_t) position, 0);
@@ -385,6 +436,7 @@ gint sci_get_position_from_col(ScintillaObject *sci, gint line, gint col)
  * @param sci Scintilla widget.
  * @param line Line.
  * @return Position. */
+GEANY_API_SYMBOL
 gint sci_get_position_from_line(ScintillaObject *sci, gint line)
 {
 	return (gint) SSM(sci, SCI_POSITIONFROMLINE, (uptr_t) line, 0);
@@ -394,16 +446,29 @@ gint sci_get_position_from_line(ScintillaObject *sci, gint line)
 /** Gets the cursor position.
  * @param sci Scintilla widget.
  * @return Position. */
+GEANY_API_SYMBOL
 gint sci_get_current_position(ScintillaObject *sci)
 {
 	return (gint) SSM(sci, SCI_GETCURRENTPOS, 0, 0);
 }
 
 
+gint sci_get_cursor_virtual_space(ScintillaObject *sci)
+{
+	gint selection_mode = sci_get_selection_mode(sci);
+
+	return selection_mode == SC_SEL_RECTANGLE || selection_mode == SC_SEL_THIN ?
+		SSM(sci, SCI_GETRECTANGULARSELECTIONCARETVIRTUALSPACE, 0, 0) :
+		SSM(sci, SCI_GETSELECTIONNCARETVIRTUALSPACE,
+			SSM(sci, SCI_GETMAINSELECTION, 0, 0), 0);
+}
+
+
 /** Sets the cursor position.
  * @param sci Scintilla widget.
  * @param position Position.
  * @param scroll_to_caret Whether to scroll the cursor in view. */
+GEANY_API_SYMBOL
 void sci_set_current_position(ScintillaObject *sci, gint position, gboolean scroll_to_caret)
 {
 	if (scroll_to_caret)
@@ -429,6 +494,7 @@ void sci_set_current_line(ScintillaObject *sci, gint line)
 /** Gets the total number of lines.
  * @param sci Scintilla widget.
  * @return The line count. */
+GEANY_API_SYMBOL
 gint sci_get_line_count(ScintillaObject *sci)
 {
 	return (gint) SSM(sci, SCI_GETLINECOUNT, 0, 0);
@@ -438,6 +504,7 @@ gint sci_get_line_count(ScintillaObject *sci)
 /** Sets the selection start position.
  * @param sci Scintilla widget.
  * @param position Position. */
+GEANY_API_SYMBOL
 void sci_set_selection_start(ScintillaObject *sci, gint position)
 {
 	SSM(sci, SCI_SETSELECTIONSTART, (uptr_t) position, 0);
@@ -447,6 +514,7 @@ void sci_set_selection_start(ScintillaObject *sci, gint position)
 /** Sets the selection end position.
  * @param sci Scintilla widget.
  * @param position Position. */
+GEANY_API_SYMBOL
 void sci_set_selection_end(ScintillaObject *sci, gint position)
 {
 	SSM(sci, SCI_SETSELECTIONEND, (uptr_t) position, 0);
@@ -463,6 +531,7 @@ void sci_set_selection(ScintillaObject *sci, gint anchorPos, gint currentPos)
  * @param sci Scintilla widget.
  * @param line Line.
  * @return The position at the end of the line. */
+GEANY_API_SYMBOL
 gint sci_get_line_end_position(ScintillaObject *sci, gint line)
 {
 	return (gint) SSM(sci, SCI_GETLINEENDPOSITION, (uptr_t) line, 0);
@@ -496,6 +565,7 @@ void sci_clear(ScintillaObject *sci)
 /** Gets the selection start position.
  * @param sci Scintilla widget.
  * @return Position. */
+GEANY_API_SYMBOL
 gint sci_get_selection_start(ScintillaObject *sci)
 {
 	return (gint) SSM(sci, SCI_GETSELECTIONSTART, 0, 0);
@@ -505,6 +575,7 @@ gint sci_get_selection_start(ScintillaObject *sci)
 /** Gets the selection end position.
  * @param sci Scintilla widget.
  * @return Position. */
+GEANY_API_SYMBOL
 gint sci_get_selection_end(ScintillaObject *sci)
 {
 	return (gint) SSM(sci, SCI_GETSELECTIONEND, 0, 0);
@@ -514,6 +585,7 @@ gint sci_get_selection_end(ScintillaObject *sci)
 /** Replaces selection.
  * @param sci Scintilla widget.
  * @param text Text. */
+GEANY_API_SYMBOL
 void sci_replace_sel(ScintillaObject *sci, const gchar *text)
 {
 	SSM(sci, SCI_REPLACESEL, 0, (sptr_t) text);
@@ -523,6 +595,7 @@ void sci_replace_sel(ScintillaObject *sci, const gchar *text)
 /** Gets the length of all text.
  * @param sci Scintilla widget.
  * @return Length. */
+GEANY_API_SYMBOL
 gint sci_get_length(ScintillaObject *sci)
 {
 	return (gint) SSM(sci, SCI_GETLENGTH, 0, 0);
@@ -533,6 +606,7 @@ gint sci_get_length(ScintillaObject *sci)
  * @param sci Scintilla widget.
  * @returns The lexer ID
  */
+GEANY_API_SYMBOL
 gint sci_get_lexer(ScintillaObject *sci)
 {
 	return (gint) SSM(sci, SCI_GETLEXER, 0, 0);
@@ -554,6 +628,7 @@ void sci_set_lexer(ScintillaObject *sci, guint lexer_id)
  * @param sci Scintilla widget.
  * @param line Line number.
  * @return Length. */
+GEANY_API_SYMBOL
 gint sci_get_line_length(ScintillaObject *sci, gint line)
 {
 	return (gint) SSM(sci, SCI_LINELENGTH, (uptr_t) line, 0);
@@ -577,6 +652,7 @@ gchar *sci_get_string(ScintillaObject *sci, guint msg, gulong wParam)
  * @param sci Scintilla widget.
  * @param line_num Line number.
  * @return A @c NULL-terminated copy of the line text. */
+GEANY_API_SYMBOL
 gchar *sci_get_line(ScintillaObject *sci, gint line_num)
 {
 	return sci_get_string(sci, SCI_GETLINE, (gulong) line_num);
@@ -590,6 +666,7 @@ gchar *sci_get_line(ScintillaObject *sci, gint line_num)
  * @param sci Scintilla widget.
  * @param len Length of @a text buffer, usually sci_get_length() + 1.
  * @param text Text buffer; must be allocated @a len + 1 bytes for null-termination. */
+GEANY_API_SYMBOL
 void sci_get_text(ScintillaObject *sci, gint len, gchar *text)
 {
 	SSM(sci, SCI_GETTEXT, (uptr_t) len, (sptr_t) text);
@@ -605,6 +682,7 @@ void sci_get_text(ScintillaObject *sci, gint len, gchar *text)
  *
  * @since 1.23 (0.17)
  */
+GEANY_API_SYMBOL
 gchar *sci_get_contents(ScintillaObject *sci, gint buffer_len)
 {
 	gchar *text;
@@ -625,6 +703,7 @@ gchar *sci_get_contents(ScintillaObject *sci, gint buffer_len)
  * @param sci Scintilla widget.
  * @param text Text buffer; must be allocated sci_get_selected_text_length() + 1 bytes
  * for null-termination. */
+GEANY_API_SYMBOL
 void sci_get_selected_text(ScintillaObject *sci, gchar *text)
 {
 	SSM(sci, SCI_GETSELTEXT, 0, (sptr_t) text);
@@ -638,6 +717,7 @@ void sci_get_selected_text(ScintillaObject *sci, gchar *text)
  *
  * @since 0.17
  */
+GEANY_API_SYMBOL
 gchar *sci_get_selection_contents(ScintillaObject *sci)
 {
 	return sci_get_string(sci, SCI_GETSELTEXT, 0);
@@ -647,6 +727,7 @@ gchar *sci_get_selection_contents(ScintillaObject *sci)
 /** Gets selected text length.
  * @param sci Scintilla widget.
  * @return Length. */
+GEANY_API_SYMBOL
 gint sci_get_selected_text_length(ScintillaObject *sci)
 {
 	return (gint) SSM(sci, SCI_GETSELTEXT, 0, 0);
@@ -664,6 +745,7 @@ gint sci_get_position_from_xy(ScintillaObject *sci, gint x, gint y, gboolean nea
  * @param sci Scintilla widget.
  * @param line Line number.
  * @return Whether @a line will be drawn on the screen. */
+GEANY_API_SYMBOL
 gboolean sci_get_line_is_visible(ScintillaObject *sci, gint line)
 {
 	return SSM(sci, SCI_GETLINEVISIBLE, (uptr_t) line, 0) != FALSE;
@@ -673,6 +755,7 @@ gboolean sci_get_line_is_visible(ScintillaObject *sci, gint line)
 /** Makes @a line visible (folding may have hidden it).
  * @param sci Scintilla widget.
  * @param line Line number. */
+GEANY_API_SYMBOL
 void sci_ensure_line_is_visible(ScintillaObject *sci, gint line)
 {
 	SSM(sci, SCI_ENSUREVISIBLE, (uptr_t) line, 0);
@@ -734,6 +817,7 @@ void sci_set_tab_width(ScintillaObject *sci, gint width)
  *
  * @since 0.15
  **/
+GEANY_API_SYMBOL
 gint sci_get_tab_width(ScintillaObject *sci)
 {
 	return (gint) SSM(sci, SCI_GETTABWIDTH, 0, 0);
@@ -744,6 +828,7 @@ gint sci_get_tab_width(ScintillaObject *sci)
  * @param sci Scintilla widget.
  * @param pos Position.
  * @return Char. */
+GEANY_API_SYMBOL
 gchar sci_get_char_at(ScintillaObject *sci, gint pos)
 {
 	return (gchar) SSM(sci, SCI_GETCHARAT, (uptr_t) pos, 0);
@@ -774,6 +859,7 @@ void sci_use_popup(ScintillaObject *sci, gboolean enable)
  *
  * @since 0.15
  **/
+GEANY_API_SYMBOL
 gboolean sci_has_selection(ScintillaObject *sci)
 {
 	if (SSM(sci, SCI_GETSELECTIONEND, 0, 0) - SSM(sci, SCI_GETSELECTIONSTART, 0, 0))
@@ -808,18 +894,13 @@ void sci_set_anchor(ScintillaObject *sci, gint pos)
 
 /** Scrolls the cursor in view.
  * @param sci Scintilla widget. */
+GEANY_API_SYMBOL
 void sci_scroll_caret(ScintillaObject *sci)
 {
 	SSM(sci, SCI_SCROLLCARET, 0, 0);
 }
 
 
-void sci_scroll_lines(ScintillaObject *sci, gint lines)
-{
-	SSM(sci, SCI_LINESCROLL, 0, lines);
-}
-
-
 void sci_scroll_columns(ScintillaObject *sci, gint columns)
 {
 	SSM(sci, SCI_LINESCROLL, (uptr_t) columns, 0);
@@ -853,6 +934,7 @@ gint sci_search_prev(ScintillaObject *sci, gint flags, const gchar *text)
  *         The @c chrgText.cpMin and @c chrgText.cpMax members of @c TextToFind are filled in
  *         with the start and end positions of the found text.
  */
+GEANY_API_SYMBOL
 gint sci_find_text(ScintillaObject *sci, gint flags, struct Sci_TextToFind *ttf)
 {
 	return (gint) SSM(sci, SCI_FINDTEXT, (uptr_t) flags, (sptr_t) ttf);
@@ -864,6 +946,7 @@ gint sci_find_text(ScintillaObject *sci, gint flags, struct Sci_TextToFind *ttf)
  * @param style The style.
  * @param font The font name.
  * @param size The font size. */
+GEANY_API_SYMBOL
 void sci_set_font(ScintillaObject *sci, gint style, const gchar *font, gint size)
 {
 	SSM(sci, SCI_STYLESETFONT, (uptr_t) style, (sptr_t) font);
@@ -878,6 +961,7 @@ void sci_set_font(ScintillaObject *sci, gint style, const gchar *font, gint size
  * @param line Line.
  * @param unfold Whether to unfold first.
  */
+GEANY_API_SYMBOL
 void sci_goto_line(ScintillaObject *sci, gint line, gboolean unfold)
 {
 	if (unfold) SSM(sci, SCI_ENSUREVISIBLE, (uptr_t) line, 0);
@@ -895,6 +979,7 @@ void sci_marker_delete_all(ScintillaObject *sci, gint marker)
  * @param sci Scintilla widget.
  * @param position Position.
  * @return Style ID. */
+GEANY_API_SYMBOL
 gint sci_get_style_at(ScintillaObject *sci, gint position)
 {
 	return (gint) SSM(sci, SCI_GETSTYLEAT, (uptr_t) position, 0);
@@ -928,13 +1013,14 @@ void sci_clear_cmdkey(ScintillaObject *sci, gint key)
  * @param start Start.
  * @param end End.
  * @param text Text will be zero terminated and must be allocated (end - start + 1) bytes. */
+GEANY_API_SYMBOL
 void sci_get_text_range(ScintillaObject *sci, gint start, gint end, gchar *text)
 {
 	struct Sci_TextRange tr;
 	tr.chrg.cpMin = start;
 	tr.chrg.cpMax = end;
 	tr.lpstrText = text;
-	SSM(sci, SCI_GETTEXTRANGE, 0, (long) &tr);
+	SSM(sci, SCI_GETTEXTRANGE, 0, (sptr_t) &tr);
 }
 
 
@@ -946,6 +1032,7 @@ void sci_get_text_range(ScintillaObject *sci, gint start, gint end, gchar *text)
  *
  * @since 0.17
  */
+GEANY_API_SYMBOL
 gchar *sci_get_contents_range(ScintillaObject *sci, gint start, gint end)
 {
 	gchar *text;
@@ -974,30 +1061,28 @@ void sci_selection_duplicate(ScintillaObject *sci)
  * @param sci Scintilla widget.
  * @param pos Position, or -1 for current.
  * @param text Text. */
+GEANY_API_SYMBOL
 void sci_insert_text(ScintillaObject *sci, gint pos, const gchar *text)
 {
 	SSM(sci, SCI_INSERTTEXT, (uptr_t) pos, (sptr_t) text);
 }
 
 
-void sci_target_from_selection(ScintillaObject *sci)
-{
-	SSM(sci, SCI_TARGETFROMSELECTION, 0, 0);
-}
-
-
+GEANY_API_SYMBOL
 void sci_set_target_start(ScintillaObject *sci, gint start)
 {
 	SSM(sci, SCI_SETTARGETSTART, (uptr_t) start, 0);
 }
 
 
+GEANY_API_SYMBOL
 void sci_set_target_end(ScintillaObject *sci, gint end)
 {
 	SSM(sci, SCI_SETTARGETEND, (uptr_t) end, 0);
 }
 
 
+GEANY_API_SYMBOL
 gint sci_replace_target(ScintillaObject *sci, const gchar *text, gboolean regex)
 {
 	return (gint) SSM(sci, (regex) ? SCI_REPLACETARGETRE : SCI_REPLACETARGET, (uptr_t) -1, (sptr_t) text);
@@ -1023,6 +1108,7 @@ void sci_set_readonly(ScintillaObject *sci, gboolean readonly)
  *
  *  @since 0.16
  */
+GEANY_API_SYMBOL
 void sci_send_command(ScintillaObject *sci, gint cmd)
 {
 	SSM(sci, cmd, 0, 0);
@@ -1032,6 +1118,7 @@ void sci_send_command(ScintillaObject *sci, gint cmd)
 /** Gets current line number.
  * @param sci Scintilla widget.
  * @return Line number. */
+GEANY_API_SYMBOL
 gint sci_get_current_line(ScintillaObject *sci)
 {
 	return (gint) SSM(sci, SCI_LINEFROMPOSITION, (uptr_t) SSM(sci, SCI_GETCURRENTPOS, 0, 0), 0);
@@ -1075,6 +1162,7 @@ gint sci_get_first_visible_line(ScintillaObject *sci)
  *
  *  @since 0.16
  */
+GEANY_API_SYMBOL
 void sci_indicator_set(ScintillaObject *sci, gint indic)
 {
 	SSM(sci, SCI_SETINDICATORCURRENT, (uptr_t) indic, 0);
@@ -1099,6 +1187,7 @@ void sci_indicator_fill(ScintillaObject *sci, gint pos, gint len)
  *
  *  @since 0.16
  */
+GEANY_API_SYMBOL
 void sci_indicator_clear(ScintillaObject *sci, gint pos, gint len)
 {
 	SSM(sci, SCI_INDICATORCLEARRANGE, (uptr_t) pos, len);
@@ -1130,6 +1219,7 @@ void sci_set_autoc_max_height(ScintillaObject *sci, gint val)
  *
  * @since 0.15
  **/
+GEANY_API_SYMBOL
 gint sci_find_matching_brace(ScintillaObject *sci, gint pos)
 {
 	return (gint) SSM(sci, SCI_BRACEMATCH, (uptr_t) pos, 0);
@@ -1169,6 +1259,7 @@ gint sci_get_pos_at_line_sel_end(ScintillaObject *sci, gint line)
 /** Gets selection mode.
  * @param sci Scintilla widget.
  * @return Selection mode. */
+GEANY_API_SYMBOL
 gint sci_get_selection_mode(ScintillaObject *sci)
 {
 	return (gint) SSM(sci, SCI_GETSELECTIONMODE, 0, 0);
@@ -1178,6 +1269,7 @@ gint sci_get_selection_mode(ScintillaObject *sci)
 /** Sets selection mode.
  * @param sci Scintilla widget.
  * @param mode Mode. */
+GEANY_API_SYMBOL
 void sci_set_selection_mode(ScintillaObject *sci, gint mode)
 {
 	SSM(sci, SCI_SETSELECTIONMODE, (uptr_t) mode, 0);
@@ -1198,6 +1290,7 @@ void sci_set_scrollbar_mode(ScintillaObject *sci, gboolean visible)
  *
  * @since 0.19
  */
+GEANY_API_SYMBOL
 void sci_set_line_indentation(ScintillaObject *sci, gint line, gint indent)
 {
 	SSM(sci, SCI_SETLINEINDENTATION, (uptr_t) line, indent);
@@ -1211,6 +1304,7 @@ void sci_set_line_indentation(ScintillaObject *sci, gint line, gint indent)
  *
  * @since 0.19
  */
+GEANY_API_SYMBOL
 gint sci_get_line_indentation(ScintillaObject *sci, gint line)
 {
 	return (gint) SSM(sci, SCI_GETLINEINDENTATION, (uptr_t) line, 0);
@@ -1241,12 +1335,6 @@ void sci_cancel(ScintillaObject *sci)
 }
 
 
-gint sci_get_target_end(ScintillaObject *sci)
-{
-	return (gint) SSM(sci, SCI_GETTARGETEND, 0, 0);
-}
-
-
 gint sci_get_position_after(ScintillaObject *sci, gint start)
 {
 	return (gint) SSM(sci, SCI_POSITIONAFTER, (uptr_t) start, 0);
