@@ -512,10 +512,19 @@ void ui_update_popup_goto_items(gboolean enable)
 }
 
 
+void ui_menu_copy_items_set_sensitive(gboolean sensitive)
+{
+	guint i, len;
+
+	len = G_N_ELEMENTS(widgets.menu_copy_items);
+	for (i = 0; i < len; i++)
+		ui_widget_set_sensitive(widgets.menu_copy_items[i], sensitive);
+}
+
+
 void ui_update_menu_copy_items(GeanyDocument *doc)
 {
 	gboolean enable = FALSE;
-	guint i, len;
 	GtkWidget *focusw = gtk_window_get_focus(GTK_WINDOW(main_widgets.window));
 
 	g_return_if_fail(doc == NULL || doc->is_valid);
@@ -533,9 +542,7 @@ void ui_update_menu_copy_items(GeanyDocument *doc)
 		enable = gtk_text_buffer_get_selection_bounds(buffer, NULL, NULL);
 	}
 
-	len = G_N_ELEMENTS(widgets.menu_copy_items);
-	for (i = 0; i < len; i++)
-		ui_widget_set_sensitive(widgets.menu_copy_items[i], enable);
+	ui_menu_copy_items_set_sensitive(enable);
 }
 
 
@@ -2088,10 +2095,23 @@ static void on_config_file_clicked(GtkWidget *widget, gpointer user_data)
 	else
 	{
 		gchar *utf8_filename = utils_get_utf8_from_locale(file_name);
-		gchar *base_name = g_path_get_basename(file_name);
-		gchar *global_file = g_build_filename(app->datadir, base_name, NULL);
+		gchar *global_file;
+		gchar *base_name = NULL;
 		gchar *global_content = NULL;
 
+		/* get the path inside app->configdir - can contain subdirectories */
+		if (g_str_has_prefix(file_name, app->configdir))
+		{
+			gsize len = strlen(app->configdir);
+			if (file_name[len] == G_DIR_SEPARATOR)
+				base_name = g_strdup(file_name + len + 1);
+		}
+
+		if (!base_name)
+			base_name = g_path_get_basename(file_name);
+
+		global_file = g_build_filename(app->datadir, base_name, NULL);
+
 		/* if the requested file doesn't exist in the user's config dir, try loading the file
 		 * from the global data directory and use its contents for the newly created file */
 		if (g_file_test(global_file, G_FILE_TEST_EXISTS))
