@@ -626,10 +626,7 @@ void win32_show_color_dialog(const gchar *colour)
 	{
 		rgb_current = cc.rgbResult;
 		g_snprintf(hex, 11, "#%02X%02X%02X",
-	      (guint) (utils_scale_round(GetRValue(rgb_current), 255)),
-	      (guint) (utils_scale_round(GetGValue(rgb_current), 255)),
-	      (guint) (utils_scale_round(GetBValue(rgb_current), 255)));
-
+			GetRValue(rgb_current), GetGValue(rgb_current), GetBValue(rgb_current));
 		editor_insert_color(doc->editor, hex);
 	}
 	g_free(hex);
